==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/NativeUIIcon.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUIIcon = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIIcon, _super);
    function NativeUIIcon() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUIIcon.prototype.get_e = function () {
        return 11;
    };
    Object.defineProperty(NativeUIIcon.prototype, "bk", {
        get: function () {
            var a = this.ae(15);
            return a;
        },
        set: function (a) {
            this.a0(15, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIIcon.prototype, "bl", {
        get: function () {
            var a = this.ae(16);
            return a;
        },
        set: function (a) {
            this.a0(16, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIIcon.prototype, "bh", {
        get: function () {
            return this.ae(44);
        },
        set: function (a) {
            this.a0(44, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIIcon.prototype, "bi", {
        get: function () {
            return this.ae(45);
        },
        set: function (a) {
            this.a0(45, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIIcon.prototype, "bj", {
        get: function () {
            return this.ae(46);
        },
        set: function (a) {
            this.a0(46, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIIcon.prototype, "bg", {
        get: function () {
            return this.ae(47);
        },
        set: function (a) {
            this.a0(47, a);
        },
        enumerable: false,
        configurable: true
    });
    NativeUIIcon.$t = markType(NativeUIIcon, 'NativeUIIcon', NativeUIComponent.$);
    return NativeUIIcon;
}(NativeUIComponent));
export { NativeUIIcon };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/NativeUIIcon.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { NativeUIComponent } from "./NativeUIComponent";
import { markType } from "./type";
/**
 * @hidden
 */
var NativeUIIcon = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(NativeUIIcon, _super);
    function NativeUIIcon() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    NativeUIIcon.prototype.get_e = function () {
        return 11;
    };
    Object.defineProperty(NativeUIIcon.prototype, "bo", {
        get: function () {
            var a = this.ag(15);
            return a;
        },
        set: function (a) {
            this.a2(15, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIIcon.prototype, "bp", {
        get: function () {
            var a = this.ag(16);
            return a;
        },
        set: function (a) {
            this.a2(16, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIIcon.prototype, "bl", {
        get: function () {
            return this.ag(44);
        },
        set: function (a) {
            this.a2(44, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIIcon.prototype, "bm", {
        get: function () {
            return this.ag(45);
        },
        set: function (a) {
            this.a2(45, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIIcon.prototype, "bn", {
        get: function () {
            return this.ag(46);
        },
        set: function (a) {
            this.a2(46, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIIcon.prototype, "bk", {
        get: function () {
            return this.ag(47);
        },
        set: function (a) {
            this.a2(47, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIIcon.prototype, "bi", {
        get: function () {
            return this.ag(62);
        },
        set: function (a) {
            this.a2(62, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(NativeUIIcon.prototype, "bj", {
        get: function () {
            return this.ag(63);
        },
        set: function (a) {
            this.a2(63, a);
        },
        enumerable: false,
        configurable: true
    });
    NativeUIIcon.$t = markType(NativeUIIcon, 'NativeUIIcon', NativeUIComponent.$);
    return NativeUIIcon;
}(NativeUIComponent));
export { NativeUIIcon };
